@@ -2,6 +2,7 @@ from typing import override, Type, Callable, TYPE_CHECKING
 
 from ormlambda.common.abstract_classes.decomposition_query import DecompositionQueryBase
 from ormlambda.common.enums.join_type import JoinType
+from ormlambda.common.interfaces.IAggregate import IAggregate
 
 if TYPE_CHECKING:
     from ormlambda import Table
@@ -34,7 +35,15 @@ class Select[T: Type[Table]](DecompositionQueryBase[T]):
     @override
     @property
     def query(self) -> str:
-        col: str = ", ".join([x.query for x in self.all_clauses])
+        cols:list[str] = []
+        for x in self.all_clauses:
+            cols.append(x.query)
+
+            if isinstance(x._row_column,IAggregate) and x._row_column.has_foreign_keys:
+                self._fk_relationship.update(x._row_column.fk_relationship)
+
+
+        col: str = ", ".join(cols)
         query: str = f"{self.CLAUSE} {col} FROM {self._table.__table_name__}"
         alias = ""
 
