@@ -80,10 +80,10 @@ class MySQLRepository(IRepositoryBase[MySQLConnection]):
         def wrapper(self: MySQLRepository, *args, **kwargs):
             with self._pool.get_connection() as cnx:
                 try:
-                    foo = func(self, cnx, *args, **kwargs)
+                    foo = func(self, cnx._cnx, *args, **kwargs)
                     return foo
                 except Exception as e:
-                    self.connection.rollback()
+                    cnx._cnx.rollback()
                     raise e
 
         return wrapper
@@ -192,10 +192,6 @@ class MySQLRepository(IRepositoryBase[MySQLConnection]):
     def create_database(self, name: str, if_exists: TypeExists = "fail") -> None:
         return CreateDatabase(self).execute(name, if_exists)
 
-    @override
-    @property
-    def connection(self) -> MySQLConnection:
-        return self._connection
 
     @property
     def database(self) -> Optional[str]:
