@@ -1,5 +1,8 @@
 from __future__ import annotations
-from typing import override, Type, TYPE_CHECKING, Any, Callable, Optional
+from typing import Iterable, override, Type, TYPE_CHECKING, Any, Callable, Optional
+import inspect
+from mysql.connector import MySQLConnection, errors, errorcode
+
 
 if TYPE_CHECKING:
     from ormlambda import Table
@@ -7,6 +10,8 @@ if TYPE_CHECKING:
     from ormlambda.common.interfaces.IStatements import OrderType
     from ormlambda.common.interfaces import IQuery, IRepositoryBase, IStatements_two_generic
     from ormlambda.common.interfaces.IRepositoryBase import TypeExists
+    from ormlambda.common.interfaces import IAggregate
+    from ormlambda.common.interfaces.IStatements import WhereTypes
 
 from ormlambda import AbstractSQLStatements
 from .clauses import DeleteQuery
@@ -23,13 +28,10 @@ from .clauses import WhereCondition
 from .clauses import Count
 from .clauses import GroupBy
 
-from mysql.connector import MySQLConnection, errors, errorcode
-
-
-import inspect
 
 from ormlambda.utils import ForeignKey, Table
 from ormlambda.common.enums import JoinType
+from . import functions as func
 
 
 class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
@@ -140,9 +142,15 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return self
 
     @override
-    def where(self, lambda_: Callable[[T], bool] = lambda: None, **kwargs) -> IStatements_two_generic[T, MySQLConnection]:
+    def where(self, conditions: WhereTypes = lambda: None, **kwargs) -> IStatements_two_generic[T, MySQLConnection]:
         # FIXME [x]: I've wrapped self._model into tuple to pass it instance attr. Idk if it's correct
-        where_query = WhereCondition[T](function=lambda_, instances=(self._model,), **kwargs)
+
+        if isinstance(conditions, Iterable):
+            for x in conditions:
+                self._query_list["where"].append(WhereCondition[T](function=x, instances=(self._model,), **kwargs))
+            return self
+
+        where_query = WhereCondition[T](function=conditions, instances=(self._model,), **kwargs)
         self._query_list["where"].append(where_query)
         return self
 
@@ -152,6 +160,18 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         self._query_list["order"].append(order)
         return self
 
+    @override
+    def concat[*Ts](self, selector: Callable[[T], tuple[*Ts]], alias: bool = True, alias_name: str = "CONCAT") -> IAggregate[T]:
+        return func.Concat[T](self._model, selector, alias=alias, alias_name=alias_name)
+
+    @override
+    def max[TProp](self, column: Callable[[T], TProp], alias: bool = True, alias_name: str = "max") -> TProp:
+        return func.Max[T](self._model, column=column, alias=alias, alias_name=alias_name)
+
+    @override
+    def min[TProp](self, column: Callable[[T], TProp], alias: bool = True, alias_name: str = "min") -> TProp:
+        return func.Min[T](self._model, column=column, alias=alias, alias_name=alias_name)
+
     @override
     def select[TValue, TFlavour, *Ts](self, selector: Optional[Callable[[T], tuple[TValue, *Ts]]] = lambda: None, *, flavour: Optional[Type[TFlavour]] = None, by: JoinType = JoinType.INNER_JOIN):
         if len(inspect.signature(selector).parameters) == 0:
@@ -198,24 +218,33 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
     def _build(self) -> str:
         query: str = ""
 
-        # self.__create_necessary_inner_join()
         for x in self.__order__:
             sub_query: Optional[list[IQuery]] = self._query_list.get(x, None)
-            if sub_query is not None:
-                if isinstance(sub_query[0], WhereCondition):
-                    query_ = self.__build_where_clause(sub_query)
+            if sub_query is None:
+                continue
 
-                # we must check if any join already exists on query string
-                elif isinstance(sub_query[0], JoinSelector):
-                    select_query: str = self._query_list["select"][0].query
-                    query_ = ""
-                    for join in sub_query:
-                        if join.query not in select_query:
-                            query_ += f"\n{join.query}"
-                else:
-                    query_ = "\n".join([x.query for x in sub_query])
+            if isinstance(sub_query[0], WhereCondition):
+                query_ = self.__build_where_clause(sub_query)
 
-                query += f"\n{query_}" if query != "" else query_
+            # we must check if any join already exists on query string
+            elif isinstance(sub_query[0], JoinSelector):
+                select_query: str = self._query_list["select"][0].query
+                query_ = ""
+                for join in sub_query:
+                    if join.query not in select_query:
+                        query_ += f"\n{join.query}"
+
+            elif isinstance((select := sub_query[0]), Select):
+                query_: str = ""
+                where_joins = self.__create_necessary_inner_join()
+                if where_joins:
+                    select._fk_relationship.update(where_joins)
+                query_ = select.query
+
+            else:
+                query_ = "\n".join([x.query for x in sub_query])
+
+            query += f"\n{query_}" if query != "" else query_
         self._query_list.clear()
         return query
 
@@ -227,3 +256,19 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
             and_, clause = q.split(" ", maxsplit=1)
             query += f" {and_} ({clause})"
         return query
+
+    def __create_necessary_inner_join(self) -> Optional[set[tuple[Type[Table], Type[Table]]]]:
+        # When we applied filters in any table that we wont select any column, we need to add manually all neccessary joins to achieve positive result.
+        if "where" not in self._query_list:
+            return None
+
+        res = []
+        for where in self._query_list["where"]:
+            where: AbstractWhere
+
+            tables = where.get_involved_tables()
+
+            if tables:
+                [res.append(x) for x in tables]
+
+        return set(res)
